<?php

namespace Bixo\Profile\Actions;

use Illuminate\Support\Str;
use Bixo\Profile\Models\Profile;
use Bixo\Profile\Scopes\ProfileResourceScope;
use Litepie\Actions\Concerns\AsAction;
use Litepie\Actions\Traits\LogsActions;
use Litepie\Database\RequestScope;

class ProfileActions
{
    use AsAction;
    use LogsActions;
    
    protected $model;
    protected $namespace = 'bixo.profile.profile';
    protected $eventClass = \Bixo\Profile\Events\ProfileAction::class;
    protected $action;
    protected $function;
    protected $request;

    public function handle(string $action, array $request)
    {
        $this->model = app(Profile::class);
        $this->action = $action;
        $this->request = $request;
        $this->function = Str::camel($action);

        $function = Str::camel($action);

        $this->dispatchActionBeforeEvent();
        $data = $this->$function($request);
        $this->dispatchActionAfterEvent();

        $this->logsAction();
        return $data;

    }

    public function paginate(array $request)
    {
        $pageLimit = isset($request['pageLimit']) ?: config('database.pagination.limit');
        $profile = $this->model
            ->pushScope(new RequestScope())
            ->pushScope(new ProfileResourceScope())
            ->paginate($pageLimit);

        return $profile;
    }

    public function simplePaginate(array $request)
    {
        $pageLimit = isset($request['pageLimit']) ?: config('database.pagination.limit');
        $profile = $this->model
            ->pushScope(new RequestScope())
            ->pushScope(new ProfileResourceScope())
            ->simplePaginate($pageLimit);

        return $profile;
    }

    function empty(array $request) {
        return $this->model->forceDelete();
    }

    function restore(array $request) {
        return $this->model->restore();
    }

    public function delete(array $request)
    {
        $ids = $request['ids'];
        $ids = collect($ids)->map(function ($id) {
            return hashids_decode($id);
        });
        return $this->model->whereIn('id', $ids)->delete();
    }

    public function options(array $request)
    {
        return $this->model
            ->pushScope(new RequestScope())
            ->pushScope(new ProfileResourceScope())
            ->take(30)->get()
            ->map(function ($row) {
                return [
                    'key' => $row->id,
                    'value' => $row->id,
                    'text' => $row->name,
                ];
            })->toArray();
    }
}
