<?php

namespace Bixo\Profile\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Profile\Events\ProfileAction as ProfileActionEvent;
use Bixo\Profile\Notifications\ProfileAction as ProfileActionNotification;
use Litepie\Actions\Concerns\AsAction;

class ProfileAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the ProfileActionEvent.
     *
     * @param   ProfileActionEvent  $event
     * @return mixed
     */
    public function handle(ProfileActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $profile.
     *
     * @param   ProfileActionEvent  $event
     * @return void
     */
    public function create(ProfileActionEvent $event)
    {
        $client = $event->profile->client;
        Notification::send($client, new ProfileActionNotification($event));
    }

    /**
     * Handle the ProfileActionEvent as a listener.
     *
     * @param   ProfileActionEvent  $event
     * @return mixed
     */
    public function asListener(ProfileActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   ProfileActionEvent  $event
     * @return bool
     */
    private function isAllowed(ProfileActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
