<?php

namespace Bixo\Profile\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Profile\Events\ProfileWorkflow as ProfileWorkflowEvent;
use Bixo\Profile\Notifications\ProfileWorkflow as ProfileWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class ProfileWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(ProfileWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $profile is submitted.
     *
     * @param ProfileWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(ProfileWorkflowEvent $event)
    {
        $client = $event->profile->client;
        Notification::send($client, new ProfileWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $profile is published.
     *
     * @param ProfileWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(ProfileWorkflowEvent $event)
    {
        $client = $event->profile->client;
        Notification::send($client, new ProfileWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $profile is approved.
     *
     * @param ProfileWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(ProfileWorkflowEvent $event)
    {
        $client = $event->profile->client;
        Notification::send($client, new ProfileWorkflowNotification($event));
    }

    /**
     * Handles the $profile workflow event as a listener.
     *
     * @param ProfileWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(ProfileWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
