<?php
namespace Bixo\Profile\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Profile\Events\ProfileAction as ProfileActionEvent;
use Bixo\Profile\Models\Profile;

class ProfileAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $profile;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param ProfileActionEvent $profile
     */
    public function __construct(ProfileActionEvent $profile)
    {
        $this->action = $event->action;
        $this->profile = $profile;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Profile Approved - ' . config('app.name'))
            ->view('profile::profile.email.action', ['data' => $this->profile]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
