<?php

namespace Bixo\Profile\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Profile\Models\Profile;

class ProfilePolicy
{

    use ProfileAction;
    use ProfileReport;
    use ProfileWorkflow;

    /**
     * Determine if the given user can view the profile.
     *
     * @param Authenticatable $user
     * @param Profile $profile
     *
     * @return bool
     */
    public function view(Authenticatable $user, Profile $profile)
    {
        if ($authUser->canDo('profile.profile.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $profile->is_owner;
    }

    /**
     * Determine if the given user can create a profile.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('profile.profile.create');
    }

    /**
     * Determine if the given user can update the given profile.
     *
     * @param Authenticatable $user
     * @param Profile $profile
     *
     * @return bool
     */
    public function update(Authenticatable $user, Profile $profile)
    {
        if ($user->canDo('profile.profile.edit') && $user->isAdmin()) {
            return true;
        }

        return $profile->is_owner;
    }

    /**
     * Determine if the given user can delete the given profile.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Profile $profile)
    {
        return $profile->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
